%	plotstreak.m
%	Matlab 6.0 Script file to plot the streaklines for rotaional 
%   flow above an infinite fixed plate.
%
% Physical parameters
viscosity = 1.0e-3;
rho = 1000.0;
rotrate = 1.0;
radius = 0.025;
height = 0.01;
% Grid parameters
id = 11;
jd = 11;
kd = 21;
% Create Matlab three-dimensional mesh
x = [0:2*id-2]*(2*radius)/(2*id-2) - radius;
y = [0:2*jd-2]*(2*radius)/(2*jd-2) - radius;
z = [0:kd-1]*height/(kd-1);
[X,Y,Z] = meshgrid(x,y,z);
% Input and transform the non-dimensional axial profile functions
if (exist ('profiles.mat')) ~= 2
    similarity_profiles %function to estimate analytical velocity components
                        %on a fine 1-D uniform mesh
end
load profiles
% % Move ua non-dimensional velocity profile function to control volume nodes
% 
zeta_va = zeta - dzeta/2.0; % position of lower control volume faces
zeta_va = [zeta_va;  zeta_va(end)+dzeta]; % position of last control volume face
va_nd = interp1(zeta_va,va_nd,zeta);
% 
% Transform radius independent variable back to dimensional variables
z_fine = sqrt(viscosity/rho/rotrate)*zeta;
% Interpolate the non-dimensional profiles onto the mesh axial positions
va_coarse = interp1(z_fine,va_nd,z);
vr_coarse = interp1(z_fine,vr_nd,z);
vt_coarse = interp1(z_fine,vt_nd,z);
p_coarse = interp1(z_fine,p_nd,z);
% Correct the boundary node values
p_coarse(1) = p_nd(1);
va_coarse(1) = 0.0;
vr_coarse(1) = 0.0;
vt_coarse(1) = 0.0;
%
U = X;
V = Y;
W = Z;
for j = 1:2*jd-1
    for i = 1:2*id-1
        for k = 1:kd
            U(i,j,k) = rotrate*(vr_coarse(k)*X(i,j,k)-vt_coarse(k)*Y(i,j,k));
            V(i,j,k) = rotrate*(vr_coarse(k)*Y(i,j,k)+vt_coarse(k)*X(i,j,k));
            W(i,j,k) = sqrt(viscosity*rotrate/rho)*va_coarse(k);
            P(i,j,k) = rho*rotrate^2*(X(i,j,k)^2+Y(i,j,k)^2)/2.0 + viscosity*rotrate*p_coarse(k);
        end
    end
end
%
haxis = axis([-radius,radius,-radius,radius,0.0,height,0,15]);
hold on;
view(60,50);

set(line([0,radius],[0,0],[0,0],'LineWidth',2,'Color','black'));
set(text('String','x','Color','black','Position',[1.0*radius,0.01*radius,0.075*height],...
    'FontAngle','italic','FontWeight','normal','FontSize',14));
set(line([0,0],[0,radius],[0,0],'LineWidth',2,'Color','black'));
set(text('String','y','Color','black','Position',[0.01*radius,1.0*radius,0.085*height],...
    'FontAngle','italic','FontWeight','normal','FontSize',14));
set(line([0,0],[0,0],[0,1.2*height],'LineWidth',2,'Color','black'));
set(text('String','z','Color','black','Position',[0.01*radius,0.01*radius,1.35*height],...
    'FontAngle','italic','FontWeight','normal','FontSize',14));

startx = [x];
starty = -radius*ones(size(startx));
startz = [0.0005*ones(size(x))];
verts1 = stream3(X,Y,Z,U,V,W,startx,starty,startz);
sl1 = streamline(verts1);
set(sl1,'Color','green');
startz = [0.001*ones(size(x))];
verts2 = stream3(X,Y,Z,U,V,W,startx,starty,startz);
sl2 = streamline(verts2);
streamparticles(verts1,'animate',Inf,'ParticleAlignment','on');


