% export2tascflow2.m
% Matlab 6.0 Script file for controlling calculation of velocity and pressure
% profiles for export to CFX-TASCflow visualization software.
%
% Physical parameters
viscosity = 1.e-03;
rho = 1000;
rotrate = 1.0;
radius = 0.025;
height = 0.01;

% Grid parameters
id = 11;
jd = 21;
kd = 1;

if (exist ('profiles.mat')) ~= 2
   makeprofile2 %function to estimate analytical velocity components
                       %on a fine 1-D uniform mesh
end
load profiles

% Move va non-dimensional velocity profile function to control volume nodes

zeta_va = zeta - dzeta/2.0; % position of lower control volume faces
zeta_va = [zeta_va;  zeta_va(end)+dzeta]; % position of last control volume faces
va_nd = interp1(zeta_va,va_nd,zeta);

% Transform radius independent variables back to dimensional variables
va = sqrt(viscosity*rotrate/rho)*va_nd;
z = sqrt(viscosity/rho/rotrate)*zeta;

% Calculate CFX-TASCflow grid properties

npts = (kd)*(jd)*(id);
dz = height/(jd-1);
index_j = [1:jd];
cfx_z = dz*(index_j - 1);
dr = radius/(id-1);
index_i = [1:id];
cfx_r = dr*(index_i - 1);

% Prepare the pro file for CFX-TASCflow

file = fopen('rsf','w');
fprintf(file,'$$$RSF %5.0f I J K U V W P \n',npts);

for i = 1:id
    
    % Transform back to dimensional variables

     vr = cfx_r(i)*rotrate*vr_nd;
     vt = cfx_r(i)*rotrate*vt_nd;
     p = viscosity*rotrate*p_nd;


     k = 1;
         % Interpolate onto the CFX-TASCflow j grid
 
         cfx_u = interp1(z,vr,cfx_z);
         cfx_v = interp1(z,vt,cfx_z);
         cfx_w = interp1(z,va,cfx_z);
         cfx_p = interp1(z,p,cfx_z);

         % Adjust the wall values
         cfx_p(1) =  p(1);
         cfx_u(1) = 0.0;
         cfx_v(1) = 0.0;
         cfx_w(1) = 0.0;

         for j = 1:jd
             fprintf(file,'%5.0f %5.0f %5.0f %20.8e %20.8e %20.8e %20.8e \n',i,j,k,cfx_u(j),cfx_v(j),cfx_w(j),cfx_p(j));
        end   
end
fclose(file);